@@ -21,8 +21,8 @@ class NotInitialized(Py2NError):
 class DeviceConnectionError(Py2NError):
     """Raised to indicate connection errors."""
 
-class DeviceUnspportedError(Py2NError):
-    """Raised to indicate unspported or non-2N device."""
+class DeviceUnsupportedError(Py2NError):
+    """Raised to indicate unsupported or non-2N device."""
 
 class ApiError(Enum):
     NOT_SUPPORTED = 1
