@@ -121,13 +121,13 @@ async def api_request(
 ) -> dict[str, Any] | None:
     """Perform REST call to device."""
     try:
-        async with aiohttp_session.get(
+        response = await aiohttp_session.get(
             url, timeout=HTTP_CALL_TIMEOUT, auth=options.auth
-        ) as response:
-            if response.content_type != CONTENT_TYPE:
-                raise DeviceUnsupportedError("invalid content type")
+        )
+        if response.content_type != CONTENT_TYPE:
+            raise DeviceUnsupportedError("invalid content type")
 
-            result: dict[str, Any] = await response.json()
+        result: dict[str, Any] = await response.json()
     except CONNECT_ERRORS as err:
         error = DeviceConnectionError(err)
         _LOGGER.debug("host %s: connect error: %r", options.host, error)
